@@ -89,7 +89,7 @@ get_base_px <- function() {
 
 sort_in_keyword_order <- function(df) {
   df %>%
-    dplyr::left_join(dplyr::select(px_keywords, "keyword", "order"),
+    dplyr::left_join(dplyr::select(pxmake::px_keywords, "keyword", "order"),
                      by = "keyword"
                      ) %>%
     dplyr::arrange(.data$order) %>%
@@ -100,7 +100,7 @@ sort_table1 <- sort_in_keyword_order
 
 sort_table2 <- function(df, languages) {
   df %>%
-    dplyr::left_join(dplyr::select(px_keywords, "keyword", "order"),
+    dplyr::left_join(dplyr::select(pxmake::px_keywords, "keyword", "order"),
                      by = "keyword"
                      ) %>%
     dplyr::arrange(.data$order, !is.na(.data$code), .data$code,
